@@ -34,9 +34,6 @@ namespace Sass
 	// convert one-line to multi-line
 	const int SASS2SCSS_CONVERT_COMMENT = 128;
 
-	// String for finding something interesting
-	const string SASS2SCSS_FIND_WHITESPACE = " \t\n\v\f\r";
-
 	// converter struct
 	// holding all states
 	struct converter
@@ -87,6 +84,9 @@ extern "C" {
 	// available to c and c++ code
 	char* sass2scss (const char* sass, const int options);
 
+	// available to c and c++ code
+	void freeme (char* str);
+
 #ifdef __cplusplus
 }
 #endif
