@@ -269,20 +269,12 @@ extern "C" {
     return 1;
   }
 
-  // caller must free the returned memory
-  char* quote (const char *str, const char quotemark) {
-    string quoted = Sass::quote(str, quotemark);
-    char *cstr = (char*) malloc(quoted.length() + 1);
-    std::strcpy(cstr, quoted.c_str());
-    return cstr;
+  const char* quote (const char *str, const char quotemark) {
+    return Sass::quote(str, quotemark).c_str();
   }
 
-  // caller must free the returned memory
-  char* unquote (const char *str) {
-    string unquoted = Sass::unquote(str);
-    char *cstr = (char*) malloc(unquoted.length() + 1);
-    std::strcpy(cstr, unquoted.c_str());
-    return cstr;
+  const char* unquote (const char *str) {
+    return Sass::unquote(str).c_str();
   }
 
 }
